@@ -21,6 +21,25 @@ char *simple = "From nobody Wed Sep 14 16:47:48 2005\n"
 	"    this is a test message\n"
 	"\n";
 
+char *simple_with_from = "From nobody@pacific.net.sg Tue Dec 04 19:52:17 2007\n"
+	"X-Envelope-From: <nobody@pacific.net.sg>\n"
+	"Received: from [127.0.0.1] (port=49353 helo=test11)\n"
+	"        by centos.nowhere.com with smtp (Exim 4.63)\n"
+	"        (envelope-from <nobody@pacific.net.sg>)\n"
+	"        id 1IzWJv-0000Ep-5f\n"
+	"        for wallace@nowhere.com; Tue, 04 Dec 2007 19:52:17 +0800\n"
+	"From: \"Wallace\" <nobody@pacific.net.sg>\n"
+	"To: wallace <wallace@nowhere.com>\n"
+	"Subject: Test 11\n"
+	"Message-Id: <E1IzWJv-0000Ep-5f@centos.nowhere.com>\n"
+	"Date: Tue, 04 Dec 2007 19:52:16 +0800\n"
+	"\n"
+	"\n"
+	"This line works, however,\n"
+	"From what I know, this line gets truncated\n"
+	"This line gets truncated\n"
+	"This other line get truncated too\n";
+
 char *rfc822 = "From nobody Wed Sep 14 16:47:48 2005\n"
 	"Content-Type: text/plain; charset=\"us-ascii\"\n"
 	"MIME-Version: 1.0\n"
@@ -33,6 +52,15 @@ char *rfc822 = "From nobody Wed Sep 14 16:47:48 2005\n"
 	"    this is a test message\n"
 	"\n";
     
+char * utf7_header = "From: \"Some Body\" <s.body@freeler.nl>\n"
+	"Subject: simple subject\n"
+	"To: =?iso-8859-1?Q?::_=5B_Arrty_=5D_::_=5B_Roy_=28L=29_St=E8phanie_=5D?=  <over.there@hotmail.com>\n"
+	"Date: Thu, 11 Oct 2007 19:00:37 +0200\n"
+	"MIME-Version: 1.0\n"
+	"\n"
+	" test message\n"
+	"\n";
+
 char *multipart_message = "From: \"Brother from another planet\" <vol@inter7.com>\n"
 	"To: \"Brother from another planet\" <vol@inter7.com>\n"
 	"Reply-to: \"Brother from another planet\" <vol@inter7.com>\n"
@@ -296,6 +324,15 @@ char *encoded_message_latin_2 = "From: =?ISO-8859-2?Q?=22Miroslav_=A9ulc_=28ford
 	"\n"
 	"test\n";
 
+char *encoded_message_utf8 = "From: nobody@nowhere.org\n"
+	"To: nobody@foo.org\n"
+	"Subject: =?utf-8?b?w6nDqcOp?=\n"
+	"MIME-Version: 1.0\n"
+	"Content-Type: text/plain\n"
+	"\n"
+	"test\n\n";
+
+
 char *multipart_mixed = "Received: from RAIVO (raivo.kisise [192.168.111.49])\n"
 	"	by test.kisise (Postfix) with ESMTP id 5C4981214C\n"
 	"	for <test@test.kisise>; Thu,  5 Oct 2006 04:18:26 +0300 (EEST)\n"
@@ -638,3 +675,4 @@ char *multipart_mixed = "Received: from RAIVO (raivo.kisise [192.168.111.49])\n"
 	"------=_NextPart_000_0059_01C6E7E6.3275C0B0--\n"
 	"\n"
 	"\n";
+
