@@ -829,7 +829,9 @@ static int _fetch_get_items(struct ImapSession *self, u64_t *uid)
 
 	if (self->fi->getInternalDate) {
 		SEND_SPACE;
-		dbmail_imap_session_buff_append(self, "INTERNALDATE \"%s\"", date_sql2imap(msginfo->internaldate));
+		char *s = date_sql2imap(msginfo->internaldate);
+		dbmail_imap_session_buff_append(self, "INTERNALDATE \"%s\"", s);
+		g_free(s);
 	}
 	if (self->fi->getSize) {
 		SEND_SPACE;
@@ -949,13 +951,14 @@ static int _fetch_get_items(struct ImapSession *self, u64_t *uid)
 	 * for db_get_msgflag()!
 	 */
 	int setSeenSet[IMAP_NFLAGS] = { 1, 0, 0, 0, 0, 0 };
-	if (self->fi->setseen && db_get_msgflag("seen", self->msg_idnr, ud->mailbox.uid) != 1) {
+
+	if ((ud->mailbox.permission == IMAPPERM_READWRITE) && self->fi->setseen && db_get_msgflag("seen", self->msg_idnr, ud->mailbox.uid) != 1) {
 		/* only if the user has an ACL which grants
 		   him rights to set the flag should the
 		   flag be set! */
 		result = acl_has_right(&ud->mailbox, ud->userid, ACL_RIGHT_SEEN);
 		if (result == -1) {
-			dbmail_imap_session_buff_append(self, "\r\n *BYE internal dbase error\r\n");
+			dbmail_imap_session_buff_append(self, "\r\n* BYE internal dbase error\r\n");
 			return -1;
 		}
 		
@@ -968,7 +971,6 @@ static int _fetch_get_items(struct ImapSession *self, u64_t *uid)
 		}
 
 		self->fi->getFlags = 1;
-		dbmail_imap_session_buff_append(self, " ");
 	}
 
 	dbmail_imap_session_buff_append(self, ")\r\n");
@@ -1538,18 +1540,18 @@ int dbmail_imap_session_discard_to_eol(struct ImapSession *self)
 	clientinfo_t *ci = self->ci;
 
 	/* loop until we get a newline terminated chunk */
+	alarm(self->timeout);
 	while (!done)  {
 		memset(buffer, 0, MAX_LINESIZE);
-		alarm(self->timeout);
 		if (fgets(buffer, MAX_LINESIZE, ci->rx) == NULL) {
-			alarm(0);
 			TRACE(TRACE_ERROR, "error reading from client");
-			return -1;
+			len = -1;
+			break;
 		}
 		len = strlen(buffer);
 		if (len <= 0) {
-			alarm(0);
-			return -1;
+			len = -1;
+			break;
 		}
 
 		/* Do we need to check for \r\n ? */
@@ -1634,7 +1636,7 @@ int dbmail_imap_session_handle_auth(struct ImapSession * self, char * username,
 		sleep(2);	/* security */
 
 		/* validation failed: invalid user/pass combination */
-		TRACE(TRACE_MESSAGE, "user (name %s) coming from [%s] login rejected", username, self->ci->ip_src);
+		TRACE(TRACE_MESSAGE, "user (name %s) coming from [%s] login rejected", username, self->ci->src_ip);
 		dbmail_imap_session_printf(self, "%s NO login rejected\r\n", self->tag);
 
 		return 1;
@@ -2447,11 +2449,14 @@ char **build_args_array_ext(struct ImapSession *self, const char *originalString
 			
 				ci_write(ci->tx, "+ OK gimme that string\r\n");
 				
+				/* dont wait forever */
+				alarm(self->timeout);
 				for (cnt = 0, dataidx = 0; cnt < quotedSize; cnt++) {
-					/* dont wait forever, but reset after every fgetc */
-					alarm(self->timeout);
-					if (! (gotc = fgetc(ci->rx)))
+					if (! (gotc = fgetc(ci->rx))) {
+						int serr = errno;
+						TRACE(TRACE_ERROR, "fgetc: [%s]", strerror(serr));
 						break;
+					}
 					
 					if (gotc == '\r')	/* only store if it is not \r */
 						continue;
@@ -2460,6 +2465,7 @@ char **build_args_array_ext(struct ImapSession *self, const char *originalString
 				}
 				
 				alarm(0);
+				TRACE(TRACE_DEBUG, "args[%d]: [%d/%d]", nargs, cnt, quotedSize);
 
 				self->args[nargs][dataidx] = '\0';	/* terminate string */
 				nargs++;
@@ -2480,7 +2486,7 @@ char **build_args_array_ext(struct ImapSession *self, const char *originalString
 					TRACE(TRACE_ERROR, "client socket has set error indicator in fgetc");
 					return NULL;
 				}
-				/* now read the rest of this line */
+				// now read the rest of this line 
 				result = dbmail_imap_session_readln(self, s);
 		
 				if (result < 0){
@@ -2492,9 +2498,9 @@ char **build_args_array_ext(struct ImapSession *self, const char *originalString
 					return NULL;
 				}
 
-				/* remove trailing \r\n */
+				// remove trailing \r\n 
 				tmp = &s[strlen(s)];
-				tmp--;	/* go before trailing \0; watch this with empty strings! */
+				tmp--;	// go before trailing \0; watch this with empty strings! 
 				while (tmp >= s && (*tmp == '\r' || *tmp == '\n')) {
 					*tmp = '\0';
 					tmp--;
@@ -2502,7 +2508,7 @@ char **build_args_array_ext(struct ImapSession *self, const char *originalString
 
 				TRACE(TRACE_DEBUG, "got extra line [%s]", s);
 
-				/* start over! */
+				// start over! 
 				i = 0;
 				continue;
 			}
