@@ -165,6 +165,7 @@ struct DbmailMessage * dbmail_message_new(void)
 {
 	struct DbmailMessage *self = g_new0(struct DbmailMessage,1);
 
+	self->internal_date = time(NULL);
 	self->envelope_recipient = g_string_new("");
 
 	/* provide quick case-insensitive header name searches */
@@ -310,9 +311,6 @@ static int _set_content(struct DbmailMessage *self, const GString *content)
 		self->raw = NULL;
 	}
 
-	//self->raw = g_byte_array_new();
-	//self->raw = g_byte_array_append(self->raw,(guint8 *)content->str, content->len+1);
-	//stream = g_mime_stream_mem_new_with_byte_array(self->raw);
 	stream = g_mime_stream_mem_new_with_buffer(content->str, content->len+1);
 	res = _set_content_from_stream(self, stream, DBMAIL_STREAM_PIPE);
 	g_mime_stream_close(stream);
@@ -332,7 +330,6 @@ static int _set_content_from_stream(struct DbmailMessage *self, GMimeStream *str
 	GMimeParser *parser;
 	gchar buf[MESSAGE_MAX_LINE_SIZE], *from = NULL;
 	ssize_t getslen, putslen;
-	FILE *tmp;
 	int res = 0;
 	gboolean firstline;
 
@@ -355,13 +352,20 @@ static int _set_content_from_stream(struct DbmailMessage *self, GMimeStream *str
 
 			// stream -> bstream (buffer) -> fstream (filter) -> mstream (in-memory copy)
 			bstream = g_mime_stream_buffer_new(stream,GMIME_STREAM_BUFFER_BLOCK_READ);
-//			mstream = g_mime_stream_mem_new();
 
-			tmp = tmpfile();
+			FILE *tmp = tmpfile();
+			if (! tmp) {
+				int serr = errno;
+				TRACE(TRACE_ERROR, "opening tmpfile failed: %s", strerror(serr));
+				res = 1;
+				break;
+			}
+
 			mstream = g_mime_stream_file_new(tmp);
 
 			assert(mstream);
 			fstream = g_mime_stream_filter_new_with_stream(mstream);
+			g_mime_stream_file_set_owner((GMimeStreamFile *)mstream, TRUE);
 			filter = g_mime_filter_crlf_new(GMIME_FILTER_CRLF_DECODE,GMIME_FILTER_CRLF_MODE_CRLF_DOTS);
 			g_mime_stream_filter_add((GMimeStreamFilter *) fstream, filter);
 
@@ -482,7 +486,7 @@ static void _register_header(const char *header, const char *value, gpointer use
 		hvalue = value;
 	}
 
-	if (! g_relation_exists(m->headers, hname, hvalue))
+	if (m->headers && (! g_relation_exists(m->headers, hname, hvalue)))
 		g_relation_insert(m->headers, hname, hvalue);
 }
 
@@ -498,8 +502,11 @@ u64_t dbmail_message_get_physid(const struct DbmailMessage *self)
 
 void dbmail_message_set_internal_date(struct DbmailMessage *self, char *internal_date)
 {
-	if (internal_date)
+	TRACE(TRACE_DEBUG,"[%s]", internal_date);
+	if (internal_date && strlen(internal_date))
 		self->internal_date = g_mime_utils_header_decode_date(internal_date, self->internal_date_gmtoff);
+	else
+		self->internal_date = time(NULL);
 }
 
 /* thisyear is a workaround for some broken gmime version. */
@@ -507,8 +514,7 @@ gchar * dbmail_message_get_internal_date(const struct DbmailMessage *self, int t
 {
 	char *res;
 	struct tm gmt;
-	if (! self->internal_date)
-		return NULL;
+	assert(self->internal_date);
 
 	res = g_new0(char, TIMESTRING_SIZE+1);
 	memset(&gmt,'\0', sizeof(struct tm));
@@ -787,7 +793,7 @@ struct DbmailMessage * dbmail_message_retrieve(struct DbmailMessage *self, u64_t
 int dbmail_message_store(struct DbmailMessage *self)
 {
 	u64_t user_idnr;
-	u64_t messageblk_idnr;
+	u64_t messageblk_idnr, physmessage_id = 0;
 	char unique_id[UID_SIZE];
 	char *hdrs, *body;
 	u64_t hdrs_size, body_size, rfcsize;
@@ -823,7 +829,7 @@ int dbmail_message_store(struct DbmailMessage *self)
 
 	hdrs = dbmail_message_hdrs_to_string(self);
 	hdrs_size = (u64_t)dbmail_message_get_hdrs_size(self, FALSE);
-	if(db_insert_message_block(hdrs, hdrs_size, self->id, &messageblk_idnr,1) < 0) {
+	if(db_insert_message_block(hdrs, hdrs_size, self->id, &physmessage_id, &messageblk_idnr,1) < 0) {
 		g_free(hdrs);
 		return -1;
 	}
@@ -832,7 +838,7 @@ int dbmail_message_store(struct DbmailMessage *self)
 	/* store body in several blocks (if needed */
 	body = dbmail_message_body_to_string(self);
 	body_size = (u64_t)dbmail_message_get_body_size(self, FALSE);
-	if (store_message_in_blocks(body, body_size, self->id) < 0) {
+	if (store_message_in_blocks(body, body_size, self->id, physmessage_id) < 0) {
 		g_free(body);
 		return -1;
 	}
@@ -1060,8 +1066,13 @@ static void insert_address_cache(u64_t physid, const char *field, InternetAddres
 	for (; ialist != NULL && ialist->address; ialist = ialist->next) {
 
 		ia = ialist->address;
-		g_return_if_fail(ia != NULL);
+		if (! ia) break;
 
+		if (ia->value.addr && g_mime_utils_text_is_8bit((unsigned char *)ia->value.addr, strlen(ia->value.addr))) {
+			TRACE(TRACE_INFO, "skip 8bit address");
+			continue;
+		}
+ 
 		rname=dbmail_iconv_str_to_db(ia->name ? ia->name: "", charset);
 		/* address fields are truncated to column width */
 		name = dm_strnesc(rname, CACHE_WIDTH_ADDR);
@@ -1301,7 +1312,7 @@ struct DbmailMessage * dbmail_message_construct(struct DbmailMessage *self,
 	// require self to be a pristine (empty) DbmailMessage.
 	g_return_val_if_fail(self->content==NULL, self);
 
-	message = g_mime_message_new(FALSE);
+	message = g_mime_message_new(TRUE);
 
 	// determine the optimal encoding type for the body: how would gmime
 	// encode this string. This will return either base64 or quopri.
@@ -1309,9 +1320,11 @@ struct DbmailMessage * dbmail_message_construct(struct DbmailMessage *self,
 		encoding = g_mime_utils_best_encoding((unsigned char *)body, strlen(body));
 
 	// set basic headers
+	TRACE(TRACE_DEBUG, "from: [%s] to: [%s] subject: [%s] body: [%s]", from, to, subject, body);
 	g_mime_message_set_sender(message, from);
 	g_mime_message_set_subject(message, subject);
-	g_mime_message_add_recipients_from_string(message, GMIME_RECIPIENT_TYPE_TO, to);
+	g_mime_message_set_header(message, "To", to);
+	g_mime_message_add_recipient(message, GMIME_RECIPIENT_TYPE_TO, "", to);
 
 	// construct mime-part
 	mime_part = g_mime_part_new();
