@@ -44,7 +44,7 @@
 #define BACKLOG 16
 
 
-#define DM_SOCKADDR_LEN 108
+#define DM_SOCKADDR_LEN NI_MAXSERV+NI_MAXHOST
 #define DM_USERNAME_LEN 100
 
 /** string length of configuration values */
@@ -112,10 +112,17 @@ typedef struct {
 
 typedef struct {
 	FILE *tx, *rx;
-	char ip_src[IPNUM_LEN];	/* client IP-number */
-	field_t clientname;	/* resolved client ip */
-	int timeout;		/* server timeout (seconds) */
-	int login_timeout;	/* login timeout (seconds) */
+	struct sockaddr_storage caddr;
+	socklen_t caddr_len;
+	char src_ip[NI_MAXHOST];  /* client IP-number */
+	char src_port[NI_MAXSERV];/* client IP-port */
+	struct sockaddr_storage saddr;
+	socklen_t saddr_len;
+	char dst_ip[NI_MAXHOST]; /* server IP-number */
+	char dst_port[NI_MAXSERV];/* server IP-port */
+	field_t clientname;	  /* resolved client ip */
+	int timeout;		  /* server timeout (seconds) */
+	int login_timeout;	  /* login timeout (seconds) */
 	void *userData;
 } clientinfo_t;
 
@@ -237,6 +244,7 @@ enum IMAP_COMMAND_TYPES {
 	IMAP_COMM_THREAD, 
 	IMAP_COMM_UNSELECT,
 	IMAP_COMM_IDLE,
+	IMAP_COMM_ID,
 	IMAP_COMM_LAST
 };
 
