@@ -39,7 +39,7 @@ const char *IMAP_COMMANDS[] = {
 	"check", "close", "expunge", "search", "fetch", "store", "copy",
 	"uid", "sort", "getquotaroot", "getquota",
 	"setacl", "deleteacl", "getacl", "listrights", "myrights",
-	"namespace","thread","unselect","idle",
+	"namespace","thread","unselect","idle","id",
 	"***NOMORE***"
 };
 
@@ -57,7 +57,7 @@ const IMAP_COMMAND_HANDLER imap_handler_functions[] = {
 	_ic_getquotaroot, _ic_getquota,
 	_ic_setacl, _ic_deleteacl, _ic_getacl, _ic_listrights,
 	_ic_myrights,
-	_ic_namespace, _ic_thread, _ic_unselect, _ic_idle,
+	_ic_namespace, _ic_thread, _ic_unselect, _ic_idle, _ic_id,
 	NULL
 };
 
@@ -304,7 +304,7 @@ int IMAPClientHandler(clientinfo_t * ci)
 		result = (*imap_handler_functions[i]) (session);
 
 		if (result == -1) {
-			TRACE(TRACE_ERROR,"command return with error [%s]", IMAP_COMMANDS[i]);
+			TRACE(TRACE_INFO, "command return with error [%s]", IMAP_COMMANDS[i]);
 			done = 1;	/* fatal error occurred, kick this user */
 		}
 
@@ -324,7 +324,7 @@ int IMAPClientHandler(clientinfo_t * ci)
 
 	/* cleanup */
 	dbmail_imap_session_printf(session, "%s OK completed\r\n", session->tag);
-	TRACE(TRACE_MESSAGE, "Closing connection for client from IP [%s]\n", session->ci->ip_src);
+	TRACE(TRACE_MESSAGE, "Closing connection for client from IP [%s]\n", session->ci->src_ip);
 	dbmail_imap_session_delete(session);
 
 	return EOF;
