@@ -104,7 +104,20 @@ int _ic_noop(struct ImapSession *self)
 	return 0;
 }
 
+int _ic_id(struct ImapSession *self)
+{
+	struct utsname buf;
+	imap_userdata_t *ud = (imap_userdata_t *) self->ci->userData;
+	if (!check_state_and_args(self, "ID", 0, 0, -1)) return 1;	/* error, return */
 
+	memset(&buf, 0, sizeof(buf));
+	uname(&buf);
+	dbmail_imap_session_printf(self, "* ID (\"name\" \"dbmail\" \"version\" \"%s\""
+		" \"os\" \"%s\" \"os-version\" \"%s\")\r\n", DBMAIL_VERSION, &buf.sysname, &buf.release);
+
+	dbmail_imap_session_printf(self, "%s OK ID completed\r\n", self->tag);
+	return 0;
+}
 /*
  * _ic_logout()
  *
@@ -151,7 +164,7 @@ int _ic_login(struct ImapSession *self)
 	if ((result = dbmail_imap_session_handle_auth(self, self->args[self->args_idx], self->args[self->args_idx+1])))
 		return result;
 	if (imap_before_smtp)
-		db_log_ip(self->ci->ip_src);
+		db_log_ip(self->ci->src_ip);
 
 	child_reg_connected_user(self->args[self->args_idx]);
 
@@ -213,7 +226,7 @@ int _ic_authenticate(struct ImapSession *self)
 	}
 
 	if (imap_before_smtp)
-		db_log_ip(self->ci->ip_src);
+		db_log_ip(self->ci->src_ip);
 
 	dbmail_imap_session_printf(self, "%s OK AUTHENTICATE completed\r\n", self->tag);
 	
@@ -678,10 +691,16 @@ int _ic_unsubscribe(struct ImapSession *self)
  *
  * executes a list command
  */
+static int dm_strcmpdata(gconstpointer a, gconstpointer b, gpointer data UNUSED)
+{
+        return strcmp((const char *)a, (const char *)b);
+}
+
 int _ic_list(struct ImapSession *self)
 {
 	imap_userdata_t *ud = (imap_userdata_t *) self->ci->userData;
 	u64_t *children = NULL;
+	GTree *shown = NULL;
 	int result;
 	size_t slen;
 	unsigned i;
@@ -738,6 +757,8 @@ int _ic_list(struct ImapSession *self)
 
 	mb = g_new0(mailbox_t,1);
 
+	shown = g_tree_new_full((GCompareDataFunc)dm_strcmpdata,NULL,(GDestroyNotify)g_free,NULL);
+
 	for (i = 0; i < nchildren; i++) {
 		gboolean show = FALSE;
 		if ((db_getmailbox_list_result(children[i], ud->userid, mb) != 0))
@@ -778,31 +799,36 @@ int _ic_list(struct ImapSession *self)
 			show = TRUE;
 		}
 
-		if (! show) continue;
-	
-		plist = NULL;
-		if (mb->no_select)
-			plist = g_list_append(plist, g_strdup("\\noselect"));
-		if (mb->no_inferiors)
-			plist = g_list_append(plist, g_strdup("\\noinferiors"));
-		if (mb->no_children)
-			plist = g_list_append(plist, g_strdup("\\hasnochildren"));
-		else
-			plist = g_list_append(plist, g_strdup("\\haschildren"));
-		
-		/* show */
-		pstring = dbmail_imap_plist_as_string(plist);
-		dbmail_imap_session_printf(self, "* %s %s \"%s\" \"%s\"\r\n", thisname, 
-				pstring, MAILBOX_SEPARATOR, mb->name);
-		
-		g_list_destroy(plist);
-		g_free(pstring);
+		if (show && (! g_tree_lookup(shown, mb->name))) {
+			char *s = g_strdup(mb->name);
+			g_tree_insert(shown, s, s);
+			plist = NULL;
+			if (mb->no_select)
+				plist = g_list_append(plist, g_strdup("\\noselect"));
+			if (mb->no_inferiors)
+				plist = g_list_append(plist, g_strdup("\\noinferiors"));
+			if (mb->no_children)
+				plist = g_list_append(plist, g_strdup("\\hasnochildren"));
+			else
+				plist = g_list_append(plist, g_strdup("\\haschildren"));
+			
+			/* show */
+			pstring = dbmail_imap_plist_as_string(plist);
+			dbmail_imap_session_printf(self, "* %s %s \"%s\" \"%s\"\r\n", thisname, 
+					pstring, MAILBOX_SEPARATOR, mb->name);
+			
+			g_list_destroy(plist);
+			g_free(pstring);
+		}
 	}
 
 
 	if (children)
 		g_free(children);
 
+	if (shown)
+		g_tree_destroy(shown);
+
 	g_free(pattern);
 	g_free(mb);
 	dbmail_imap_session_printf(self, "%s OK %s completed\r\n", self->tag, thisname);
