@@ -1010,9 +1010,8 @@ int check_msg_set(const char *s)
 char *date_sql2imap(const char *sqldate)
 {
         struct tm tm_sql_date;
-	time_t ltime;
         char *last;
-	char t[IMAP_INTERNALDATE_LEN];
+	char _imapdate[IMAP_INTERNALDATE_LEN] = IMAP_STANDARD_DATE;
 	char q[IMAP_INTERNALDATE_LEN];
 
 	// bsd needs:
@@ -1020,23 +1019,15 @@ char *date_sql2imap(const char *sqldate)
 	
         last = strptime(sqldate,"%Y-%m-%d %H:%M:%S", &tm_sql_date);
         if ( (last == NULL) || (*last != '\0') ) {
+		// Could not convert date - something went wrong - using default IMAP_STANDARD_DATE
                 strcpy(_imapdate, IMAP_STANDARD_DATE);
-                return _imapdate;
+                return g_strdup(_imapdate);
         }
 
         strftime(q, sizeof(q), "%d-%b-%Y %H:%M:%S", &tm_sql_date);
-
-	ltime = mktime (&tm_sql_date);
-	localtime_r(&ltime, &tm_sql_date);
-	strftime(t, sizeof(t), "%z", &tm_sql_date);
-	if (t[0] != '%') {
-		snprintf(_imapdate,IMAP_INTERNALDATE_LEN, "%s %s", q, t);
-		return _imapdate;
-	}
-	// oops, no %z on solaris (FIXME)
 	snprintf(_imapdate,IMAP_INTERNALDATE_LEN, "%s +0000", q);
 	
-        return _imapdate;
+        return g_strdup(_imapdate);
 }
 
 
@@ -1188,6 +1179,10 @@ int g_tree_merge(GTree *a, GTree *b, int condition)
 		case IST_SUBSEARCH_AND:
 			type=g_strdup("AND");
 			/* delete from A all keys not in B */
+
+			if (! g_tree_nnodes(a) > 0)
+				break;
+
 			merger->tree = b;
 			merger->condition = IST_SUBSEARCH_AND;
 			g_tree_foreach(a,(GTraverseFunc)traverse_tree_merger, &merger);
@@ -1226,6 +1221,7 @@ int g_tree_merge(GTree *a, GTree *b, int condition)
 				g_tree_steal(b,keys->data);
 				g_tree_insert(a,key,value);
 
+				TRACE(TRACE_DEBUG, "moved item between trees");
 				if (! g_list_next(keys))
 					break;
 				
@@ -1236,11 +1232,11 @@ int g_tree_merge(GTree *a, GTree *b, int condition)
 		case IST_SUBSEARCH_NOT:
 			type=g_strdup("NOT");
 			
-			keys = g_tree_keys(b);
-			
-			if (! g_list_length(keys))
+			if (! g_tree_nnodes(b) > 0)
 				break;
 			
+			keys = g_tree_keys(b);
+			
 			while (keys->data) {
 				// remove from A keys also in B 
 				if (g_tree_lookup(a,keys->data)) {
@@ -2219,9 +2215,11 @@ char * dbmail_iconv_db_to_utf7(const char* str_in)
 	return g_mime_utils_header_encode_text(str_in);
 }
 
-/* work around a bug in gmime (< 2.2.10) where utf7 strings are not completely decoded */
 char * dbmail_iconv_decode_text(const char *in)
 {
+	return g_mime_utils_header_decode_text(in);
+#if 0
+	/* work around a bug in gmime (< 2.2.10) where utf7 strings are not completely decoded */
 	size_t i=0, l=0, r=0, len, wlen=0;
 	char p2=0, p = 0, c, n = 0;
 	char *res, *s;
@@ -2277,7 +2275,7 @@ char * dbmail_iconv_decode_text(const char *in)
 	g_string_free(str,FALSE);
 
 	return res;
-
+#endif
 }
 /*
  * dbmail_iconv_decode_address
@@ -2289,6 +2287,8 @@ char * dbmail_iconv_decode_text(const char *in)
  */
 char * dbmail_iconv_decode_address(char *address)
 {
+	return g_mime_utils_header_decode_phrase(address);
+#if 0
 	InternetAddressList *l;
 	char *r = NULL, *t = NULL, *s = NULL;
 
@@ -2320,6 +2320,7 @@ char * dbmail_iconv_decode_address(char *address)
 	pack_char(r,'"');
 
 	return r;
+#endif
 }
 
 char * dbmail_iconv_decode_field(const char *in, const char *charset, gboolean isaddr)
@@ -2538,6 +2539,7 @@ char * imap_cleanup_address(const char *a)
 	
 	l = strlen(inptr);
 
+	TRACE(TRACE_DEBUG, "[%s]", inptr);
 	for (i = 0; i < l - 1; i++) {
 
 		next = inptr[i+1];
@@ -2605,6 +2607,7 @@ char * imap_cleanup_address(const char *a)
 
 	r = s->str;
 	g_string_free(s,FALSE);
+	TRACE(TRACE_DEBUG,"[%s]", r);
 	return r;
 }
 
