@@ -130,7 +130,7 @@ static int send_mail(struct DbmailMessage *message,
 			TRACE(TRACE_MESSAGE, "could not prepare 'from' address.");
 			return 1;
 		}
-		sendmail_command = g_strconcat(sendmail, " -f ", escaped_from, " ", escaped_to, NULL);
+		sendmail_command = g_strconcat(sendmail, " -i -f ", escaped_from, " ", escaped_to, NULL);
 		g_free(escaped_to);
 		g_free(escaped_from);
 		if (!sendmail_command) {
@@ -156,9 +156,7 @@ static int send_mail(struct DbmailMessage *message,
 		// This is a hack so forwards can give a From line.
 		if (preoutput)
 			fprintf(mailpipe, "%s\n", preoutput);
-		// This function will dot-stuff the message.
-		db_send_message_lines(mailpipe, message->id, -2, 1);
-		break;
+		// fall-through
 	case SENDMESSAGE:
 		message_string = dbmail_message_to_string(message);
 		fprintf(mailpipe, "%s", message_string);
@@ -336,10 +334,42 @@ int send_vacation(struct DbmailMessage *message,
  * Send an automatic reply.
  */
 #define REPLY_DAYS 7
-static int send_reply(struct DbmailMessage *message, const char *body)
+static int check_destination(struct DbmailMessage *message, GList *aliases)
+{
+	gboolean check = FALSE;
+	GList *to, *cc, *recipients;
+	to = dbmail_message_get_header_addresses(message, "To");
+	cc = dbmail_message_get_header_addresses(message, "Cc");
+	recipients = g_list_concat(to, cc);
+	if (! recipients)
+		TRACE(TRACE_DEBUG, "no recipients??");
+
+	while (recipients && (! check)) {
+		char *addr = (char *)recipients->data;
+		aliases = g_list_first(aliases);
+		while (addr && aliases && (!check)) {
+			char *alias = (char *)aliases->data;
+			if (alias && MATCH(alias, addr)) {
+				TRACE(TRACE_DEBUG, "valid alias found as recipient [%s]", alias);
+				check = TRUE;
+				break;
+			}
+			if (! g_list_next(aliases)) break;
+			aliases = g_list_next(aliases);
+		}
+		if (! g_list_next(recipients)) break;
+		recipients = g_list_next(recipients);
+	}
+
+	g_list_destroy(recipients);
+	return check;
+}
+
+static int send_reply(struct DbmailMessage *message, const char *body, GList *aliases)
 {
 	const char *from, *to, *subject;
 	const char *x_dbmail_reply;
+	char *handle;
 	int result;
 
 	x_dbmail_reply = dbmail_message_get_header(message, "X-Dbmail-Reply");
@@ -347,10 +377,15 @@ static int send_reply(struct DbmailMessage *message, const char *body)
 		TRACE(TRACE_MESSAGE, "reply loop detected [%s]", x_dbmail_reply);
 		return 0;
 	}
-	
-	subject = dbmail_message_get_header(message, "Subject");
 
+	if (! check_destination(message, aliases)) {
+		TRACE(TRACE_MESSAGE, "no valid destination ");
+		return 0;
+	}
+
+	subject = dbmail_message_get_header(message, "Subject");
 	from = dbmail_message_get_header(message, "Delivered-To");
+
 	if (!from)
 		from = message->envelope_recipient->str;
 	if (!from)
@@ -368,7 +403,10 @@ static int send_reply(struct DbmailMessage *message, const char *body)
 		return 0;
 	}
 
-	if (db_replycache_validate(to, from, "replycache", REPLY_DAYS) != DM_SUCCESS) {
+	handle = dm_md5((const unsigned char * const)body);
+
+	if (db_replycache_validate(to, from, handle, REPLY_DAYS) != DM_SUCCESS) {
+		g_free(handle);
 		TRACE(TRACE_DEBUG, "skip auto-reply");
 		return 0;
 	}
@@ -376,15 +414,16 @@ static int send_reply(struct DbmailMessage *message, const char *body)
 	char *newsubject = g_strconcat("Re: ", subject, NULL);
 
 	struct DbmailMessage *new_message = dbmail_message_new();
-	new_message = dbmail_message_construct(new_message, from, to, newsubject, body);
+	new_message = dbmail_message_construct(new_message, to, from, newsubject, body);
 	dbmail_message_set_header(new_message, "X-DBMail-Reply", from);
 
 	result = send_mail(new_message, to, from, NULL, SENDMESSAGE, SENDMAIL);
 
 	if (result == 0) {
-		db_replycache_register(to, from, "replycache");
+		db_replycache_register(to, from, handle);
 	}
 
+	g_free(handle);
 	g_free(newsubject);
 	dbmail_message_free(new_message);
 
@@ -417,7 +456,7 @@ static int execute_auto_ran(struct DbmailMessage *message, u64_t useridnr)
 	if (strcasecmp(val, "yes") == 0)
 		do_auto_reply = 1;
 
-	if (do_auto_notify != 0) {
+	if (do_auto_notify) {
 		TRACE(TRACE_DEBUG, "starting auto-notification procedure");
 
 		if (db_get_notify_address(useridnr, &notify_address) != 0)
@@ -426,7 +465,7 @@ static int execute_auto_ran(struct DbmailMessage *message, u64_t useridnr)
 			if (notify_address == NULL)
 				TRACE(TRACE_DEBUG, "no notification address specified, skipping");
 			else {
-				TRACE(TRACE_DEBUG, "sending notifcation to [%s]", notify_address);
+				TRACE(TRACE_DEBUG, "sending notification to [%s]", notify_address);
 				if (send_notification(message, notify_address) < 0) {
 					TRACE(TRACE_ERROR, "error in call to send_notification.");
 					g_free(notify_address);
@@ -437,7 +476,7 @@ static int execute_auto_ran(struct DbmailMessage *message, u64_t useridnr)
 		}
 	}
 
-	if (do_auto_reply != 0) {
+	if (do_auto_reply) {
 		TRACE(TRACE_DEBUG, "starting auto-reply procedure");
 
 		if (db_get_reply_body(useridnr, &reply_body) != 0)
@@ -446,7 +485,8 @@ static int execute_auto_ran(struct DbmailMessage *message, u64_t useridnr)
 			if (reply_body == NULL || reply_body[0] == '\0')
 				TRACE(TRACE_DEBUG, "no reply body specified, skipping");
 			else {
-				if (send_reply(message, reply_body) < 0) {
+				GList *aliases = auth_get_user_aliases(useridnr);
+				if (send_reply(message, reply_body, aliases) < 0) {
 					TRACE(TRACE_ERROR, "error in call to send_reply");
 					g_free(reply_body);
 					return -1;
@@ -462,7 +502,7 @@ static int execute_auto_ran(struct DbmailMessage *message, u64_t useridnr)
 
 
 int store_message_in_blocks(const char *message, u64_t message_size,
-			    u64_t msgidnr) 
+			    u64_t msgidnr, u64_t physmsg_id) 
 {
 	u64_t tmp_messageblk_idnr;
 	u64_t rest_size = message_size;
@@ -476,9 +516,9 @@ int store_message_in_blocks(const char *message, u64_t message_size,
 			      rest_size : READ_BLOCK_SIZE);
 		rest_size = (rest_size < READ_BLOCK_SIZE ?
 			     0 : rest_size - READ_BLOCK_SIZE);
-		TRACE(TRACE_DEBUG, "inserting message [%s]", &message[offset]);
+		TRACE(TRACE_DEBUG, "inserting message: size [%llu] block[%d]", message_size, block_nr);
 		if (db_insert_message_block(&message[offset],
-					    block_size, msgidnr,
+					    block_size, msgidnr, &physmsg_id,
 					    &tmp_messageblk_idnr,0) < 0) {
 			TRACE(TRACE_ERROR, "db_insert_message_block() failed");
 			return -1;
