@@ -93,7 +93,7 @@ int sort_load_driver(void)
 	return 0;
 }
 
-sort_result_t *sort_process(u64_t user_idnr, struct DbmailMessage *message)
+sort_result_t *sort_process(u64_t user_idnr, struct DbmailMessage *message, const char *mailbox)
 {
 	if (!sort)
 		sort_load_driver();
@@ -101,7 +101,7 @@ sort_result_t *sort_process(u64_t user_idnr, struct DbmailMessage *message)
 		TRACE(TRACE_ERROR, "Error loading sort driver");
 		return NULL;
 	}
-	return sort->process(user_idnr, message);
+	return sort->process(user_idnr, message, mailbox);
 }
 
 sort_result_t *sort_validate(u64_t user_idnr, char *scriptname)
